..
    Copyright (C) 2020 CERN
    Copyright (C) 2020 Cottage Labs LLP.

    invenio-swh is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

=============
 invenio-swh
=============

.. image:: https://github.com/inveniosoftware/invenio-swh/workflows/CI/badge.svg
        :target: https://github.com/inveniosoftware/invenio-swh/actions?query=workflow%3ACI

.. image:: https://img.shields.io/coveralls/inveniosoftware/invenio-swh.svg
        :target: https://coveralls.io/r/inveniosoftware/invenio-swh

.. image:: https://img.shields.io/github/tag/inveniosoftware/invenio-swh.svg
        :target: https://github.com/inveniosoftware/invenio-swh/releases

.. image:: https://img.shields.io/pypi/dm/invenio-swh.svg
        :target: https://pypi.python.org/pypi/invenio-swh

.. image:: https://img.shields.io/github/license/inveniosoftware/invenio-swh.svg
        :target: https://github.com/inveniosoftware/invenio-swh/blob/master/LICENSE

Support for onward deposit of software artifacts to Software Heritage.

Development of this Invenio module is being `funded through a subgrant
<https://www.softwareheritage.org/2020/10/27/connecting-scholarly-repositories-with-the-software-heritage-archive/>`_
from `Software Heritage <https://github.com/softwareheritage>`_, as a result of a
grant given by the `Alfred P. Sloan Foundation <https://sloan.org/>`_ to increase
the coverage of the Software Heritage archive.

The development plan and scope is available `as a Google Doc
<https://docs.google.com/document/d/1z0ItQa8e2bFAha_9NtEG3hd1ZJCV6T4Zi4wrXWRdTfo>`_.

Further documentation will be available on
https://invenio-swh.readthedocs.io/
